@@ -25,7 +25,6 @@ from fastapi_cloud_cli.utils.api import APIClient
 from fastapi_cloud_cli.utils.apps import AppConfig, get_app_config, write_app_config
 from fastapi_cloud_cli.utils.auth import is_logged_in
 from fastapi_cloud_cli.utils.cli import get_rich_toolkit, handle_http_errors
-from fastapi_cloud_cli.utils.env import validate_environment_variable_name
 
 logger = logging.getLogger(__name__)
 
@@ -49,7 +48,11 @@ def _should_exclude_entry(path: Path) -> bool:
 
 def archive(path: Path) -> Path:
     logger.debug("Starting archive creation for path: %s", path)
-    files = rignore.walk(path, should_exclude_entry=_should_exclude_entry)
+    files = rignore.walk(
+        path,
+        should_exclude_entry=_should_exclude_entry,
+        additional_ignore_paths=[".fastapicloudignore"],
+    )
 
     temp_dir = tempfile.mkdtemp()
     logger.debug("Created temp directory: %s", temp_dir)
@@ -64,6 +67,7 @@ def archive(path: Path) -> Path:
             if filename.is_dir():
                 continue
 
+            logger.debug("Adding %s to archive", filename.relative_to(path))
             tar.add(filename, arcname=filename.relative_to(path))
             file_count += 1
 
@@ -225,12 +229,6 @@ def _get_apps(team_id: str) -> List[AppResponse]:
     return [AppResponse.model_validate(app) for app in data]
 
 
-def _create_environment_variables(app_id: str, env_vars: Dict[str, str]) -> None:
-    with APIClient() as client:
-        response = client.patch(f"/apps/{app_id}/environment-variables/", json=env_vars)
-        response.raise_for_status()
-
-
 def _stream_build_logs(deployment_id: str) -> Generator[str, None, None]:
     with APIClient() as client:
         with client.stream(
@@ -395,45 +393,6 @@ def _wait_for_deployment(
                     last_message_changed_at = time.monotonic()  # pragma: no cover
 
 
-def _setup_environment_variables(toolkit: RichToolkit, app_id: str) -> None:
-    if not toolkit.confirm("Do you want to setup environment variables?", tag="env"):
-        return
-
-    toolkit.print_line()
-
-    env_vars = {}
-
-    while True:
-        key = toolkit.input(
-            "Enter the environment variable name: [ENTER to skip]", required=False
-        )
-
-        if key.strip() == "":
-            break
-
-        if not validate_environment_variable_name(key):
-            toolkit.print(
-                "[error]Invalid environment variable name.",
-            )
-
-        else:
-            value = toolkit.input(
-                "Enter the environment variable value:", password=True
-            )
-
-            env_vars[key] = value
-
-        toolkit.print_line()
-
-    toolkit.print_line()
-
-    with toolkit.progress("Setting up environment variables...") as progress:
-        with handle_http_errors(progress):
-            _create_environment_variables(app_id, env_vars)
-
-        progress.log("Environment variables set up successfully!")
-
-
 class SignupToWaitingList(BaseModel):
     email: EmailStr
     name: Optional[str] = None
@@ -601,9 +560,6 @@ def deploy(
             logger.debug("No app config found, configuring new app")
             app_config = _configure_app(toolkit, path_to_deploy=path_to_deploy)
             toolkit.print_line()
-
-            _setup_environment_variables(toolkit, app_config.app_id)
-            toolkit.print_line()
         else:
             logger.debug("Existing app config found, proceeding with deployment")
             toolkit.print("Deploying app...")
